@@ -21,6 +21,7 @@ from .literals import (
     ContextType,
     CostCategoryInheritedValueDimensionNameType,
     CostCategoryRuleTypeType,
+    CostCategorySplitChargeMethodType,
     CostCategoryStatusType,
     DimensionType,
     FindingReasonCodeType,
@@ -64,6 +65,8 @@ __all__ = (
     "CostCategoryProcessingStatusTypeDef",
     "CostCategoryReferenceTypeDef",
     "CostCategoryRuleTypeDef",
+    "CostCategorySplitChargeRuleParameterTypeDef",
+    "CostCategorySplitChargeRuleTypeDef",
     "CostCategoryTypeDef",
     "CostCategoryValuesTypeDef",
     "CoverageByTimeTypeDef",
@@ -342,6 +345,37 @@ CostCategoryRuleTypeDef = TypedDict(
     total=False,
 )
 
+CostCategorySplitChargeRuleParameterTypeDef = TypedDict(
+    "CostCategorySplitChargeRuleParameterTypeDef",
+    {
+        "Type": Literal["ALLOCATION_PERCENTAGES"],
+        "Values": List[str],
+    },
+)
+
+_RequiredCostCategorySplitChargeRuleTypeDef = TypedDict(
+    "_RequiredCostCategorySplitChargeRuleTypeDef",
+    {
+        "Source": str,
+        "Targets": List[str],
+        "Method": CostCategorySplitChargeMethodType,
+    },
+)
+_OptionalCostCategorySplitChargeRuleTypeDef = TypedDict(
+    "_OptionalCostCategorySplitChargeRuleTypeDef",
+    {
+        "Parameters": List["CostCategorySplitChargeRuleParameterTypeDef"],
+    },
+    total=False,
+)
+
+
+class CostCategorySplitChargeRuleTypeDef(
+    _RequiredCostCategorySplitChargeRuleTypeDef, _OptionalCostCategorySplitChargeRuleTypeDef
+):
+    pass
+
+
 _RequiredCostCategoryTypeDef = TypedDict(
     "_RequiredCostCategoryTypeDef",
     {
@@ -356,6 +390,7 @@ _OptionalCostCategoryTypeDef = TypedDict(
     "_OptionalCostCategoryTypeDef",
     {
         "EffectiveEnd": str,
+        "SplitChargeRules": List["CostCategorySplitChargeRuleTypeDef"],
         "ProcessingStatus": List["CostCategoryProcessingStatusTypeDef"],
         "DefaultValue": str,
     },
@@ -469,6 +504,7 @@ _OptionalCreateCostCategoryDefinitionRequestRequestTypeDef = TypedDict(
     "_OptionalCreateCostCategoryDefinitionRequestRequestTypeDef",
     {
         "DefaultValue": str,
+        "SplitChargeRules": List["CostCategorySplitChargeRuleTypeDef"],
     },
     total=False,
 )
@@ -2030,6 +2066,7 @@ _OptionalUpdateCostCategoryDefinitionRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateCostCategoryDefinitionRequestRequestTypeDef",
     {
         "DefaultValue": str,
+        "SplitChargeRules": List["CostCategorySplitChargeRuleTypeDef"],
     },
     total=False,
 )
